@@ -564,15 +564,20 @@ class ModelSet:
 
     # shows a tree for the given ticker and time series
     def create_model_map(
-        self, ticker, time_series="MO_RIS_REV", tree=True, notebook=True
+        self,
+        ticker,
+        col_for_labels="time_series_name",
+        time_series_name="MO_RIS_REV",
+        tree=True,
+        notebook=True,
     ):
         model = self.models[ticker]
-
         return model.create_model_map(
-            time_series=time_series,
+            time_series_name=time_series_name,
             tree=tree,
+            col_for_labels=col_for_labels,
             notebook=notebook,
-            common_time_series=self._common_time_series_names,
+            common_time_series=self.common_time_series,
         )
 
     # get a list of time series from the default dataframe
@@ -658,7 +663,7 @@ class ModelSet:
             # df = df.sort_values(["period_name", "name_index"])
 
             res = list(reduce(lambda i, j: i & j, (set(x) for x in list_all)))
-            self._common_time_series_names = res
+            self.common_time_series = res
 
             df = df_filter(df, "time_series_name", res)
 
@@ -840,11 +845,12 @@ class ModelSet:
         ticker_list = list(set(list(df["ticker"])))
 
         for ticker in ticker_list:
+            # print(return_series)
             self.models[ticker].model_fit(return_series)
-            try:
-                dict_summary[ticker] = self.models[ticker].summary()
-            except:
-                self.log.write("Missing scenario for " + ticker)
+            # try:
+            dict_summary[ticker] = self.models[ticker].summary()
+            # except:
+            #    self.log.write("Missing scenario for " + ticker)
 
         return dict_summary
 
@@ -877,7 +883,7 @@ class ModelMap:
         config: Config = None,
         ticker=None,
         model=None,
-        time_series="MO_RIS_REV",
+        time_series_name="MO_RIS_REV",
         col_for_labels="time_series_name",
         tree=True,
         common_size_tree=True,
@@ -899,7 +905,7 @@ class ModelMap:
         else:
             raise TypeError("You must pass in either a ticker or model")
 
-        self.time_series = time_series
+        self.time_series = time_series_name
         self.col_for_labels = col_for_labels
         self.tree = tree
         self.common_size_tree = common_size_tree
@@ -1169,11 +1175,12 @@ class ModelMap:
 
     # lists out all the nodes
     def list_time_series(self, search=""):
-        print("Nodes:")
+        list_out = []
         if self.nodes:
             for node in self.nodes:
                 if re.match(f".*{search}.*", node["title"]):
-                    print(node["title"])
+                    list_out.append(node["title"].split(":")[0])
+        return list_out
 
     # creates chart of given time series:
     def create_time_series_chart(self, time_series_name):
@@ -1282,7 +1289,8 @@ class Model:
 
     def create_model_map(
         self,
-        time_series="MO_RIS_REV",
+        time_series_name="MO_RIS_REV",
+        col_for_labels="time_series_name",
         tree=True,
         notebook=False,
         common_time_series=None,
@@ -1290,7 +1298,8 @@ class Model:
         mm = ModelMap(
             config=self.config,
             model=self,
-            time_series=time_series,
+            time_series_name=time_series_name,
+            col_for_labels=col_for_labels,
             tree=tree,
             notebook=notebook,
             common_time_series=common_time_series,
@@ -1396,10 +1405,10 @@ class Model:
             df.iloc[0][["period_name", "period_end_date"]]
         ).T.reset_index()[["period_name", "period_end_date"]]
 
-    def get_guidance(self):
+    def guidance(self):
         df = self.gt.get_file(self.ticker, "guidance")
         df = df.dropna()
-        self.guidance = df
+        self._guidance = df
         return df
 
     def get_driverlibrary(self, force=False):
@@ -1690,7 +1699,7 @@ class Model:
                     filter_string, case=False
                 )
             ]
-        self.describe_drivers = df_drivers_summary
+        self._describe_drivers = df_drivers_summary
         return df_drivers_summary
 
     def historical_data_frame(self):  # if cache = true save locally?
@@ -1828,6 +1837,8 @@ class Model:
 
         url = get_forecast_url(self.csin, self.latest_version, self.config.mds_host)
 
+        # print(url)
+
         scenario_url = (
             f"{self.config.mds_host}/"
             f"{SCENARIO_URL.format(csin=self.csin, version=self.latest_version)}"
@@ -1835,13 +1846,22 @@ class Model:
 
         scenario_response = get_request(scenario_url, headers=self.api_headers)
 
+        # print("scenario response"+scenario_response)
+
         scenario_json = scenario_response.json()
+        # print("scenario json"+scenario_json)
+
         scenario_id_url = map_scenario_urls(scenario_json).get(self.uuid)
 
+        # print("uuid"+str(self.uuid))
+        # print("scenario id url: "+str(scenario_id_url))
+
         if scenario_id_url is None:
-            self.log.write(
+            # self.log.write(
+            print(
                 "Scenario ID for " + scenario_url + " is None.  Perhaps max scenarios."
             )
+            # )
             return
 
         print(self.ticker + " scenario_id_url: " + str(scenario_id_url))
