@@ -290,10 +290,10 @@ def send_scenario(
     scenario_url = (
         f"{mds_host}/{SCENARIO_URL.format(csin=csin, version=latest_version)}"
     )
-    print("scenario_url: " + scenario_url)
+    # print("scenario_url: " + scenario_url)
 
     scenario_response = post_request(url=scenario_url, headers=auth_headers, json=data)
-    print(scenario_response.text)
+    # print(scenario_response.text)
 
     return scenario_response
 
@@ -505,9 +505,9 @@ def get_scenarios(ticker, auth_headers, mds_host=settings.MDS_HOST):
 
 
 def post_request(url, headers, json):
-    response = requests.post(url=url, headers=headers, json=json)
+    response = requests.post(url=url, headers=headers, json=json, verify=False)
     if check_throttle_limit(response):
-        response = requests.post(url=url, headers=headers, json=json)
+        response = requests.post(url=url, headers=headers, json=json, verify=False)
 
     return response
 
